@@ -202,7 +202,6 @@ LibraryBrowser.getSourceList = function() {
     }
 
     sourceList = sourceList.unique();
-    qDebug("sourceList: ", sourceList);
 
     return sourceList;
 };
@@ -1267,11 +1266,11 @@ LibraryBrowser.initDb = function(dropTables) {
         var err = db.lastError();
         QMessageBox.warning(null,
                         qsTr("DB error"),
-                        qsTr("Plugin LibraryBrowser: cannot connect to DB.\n" +
+                        "Plugin LibraryBrowser: cannot connect to DB.\n" +
                              "Driver error: %1\n" +
                              "Database error: %2\n" +
                              "Database file: %3\n" +
-                             "Library browser will not be available.")
+                             "Library browser will not be available."
                              .arg(err.driverText())
                              .arg(err.databaseText())
                              .arg(db.databaseName())
@@ -1322,7 +1321,7 @@ LibraryBrowser.syncAll = function(progressDialog, startUp) {
     if (startUp && !force) {
         var updateOnStartup = RSettings.getBoolValue("LibraryBrowser/UpdateOnStartup", true);
         if (!updateOnStartup) {
-            // setting, not cancelation:
+            // setting, not cancellation:
             return true;
         }
     }
