@@ -150,6 +150,9 @@ function getPtr(p) {
         if (isFunction(p.data)) {
             return p.data();
         }
+        else {
+            return p;
+        }
     }
 }
 
@@ -568,7 +571,12 @@ function isEllipseEntity(obj) {
  * \return true if the given object is an ellipse arc entity (REllipseEntity).
  */
 function isEllipseArcEntity(obj) {
-    return (isOfType(obj, REllipseEntity) || isOfType(obj, REllipseEntityPointer)) && !obj.isFullEllipse();
+    if (RSettings.getQtVersion() < 0x060000) {
+        return (isOfType(obj, REllipseEntity) || isOfType(obj, REllipseEntityPointer)) && !obj.isFullEllipse();
+    }
+    else {
+        return isOfType(obj, REllipseEntity);
+    }
 }
 
 /**
@@ -2262,6 +2270,54 @@ String.prototype.regexLastIndexOf = function(regex, startpos) {
     return lastIndexOf;
 };
 
+String.prototype.padStart = function(targetLength, padString) {
+    targetLength = targetLength >> 0; //floor if number or convert non-number to 0;
+    padString = String(typeof padString !== 'undefined' ? padString : ' ');
+    if (this.length > targetLength) {
+        return String(this);
+    } else {
+        targetLength = targetLength - this.length;
+        if (targetLength > padString.length) {
+            padString += padString.repeat(targetLength / padString.length); //append to original to ensure we are longer than needed
+        }
+        return padString.slice(0, targetLength) + String(this);
+    }
+};
+
+String.prototype.repeat = function(count) {
+    var str = '' + this;
+    // To convert string to integer.
+    count = +count;
+    // Check NaN
+    if (count != count)
+        count = 0;
+
+    if (count < 0)
+        throw new RangeError('repeat count must be non-negative');
+
+    if (count == Infinity)
+        throw new RangeError('repeat count must be less than infinity');
+
+    count = Math.floor(count);
+    if (str.length == 0 || count == 0)
+        return '';
+
+    // Ensuring count is a 31-bit integer allows us to heavily optimize the
+    // main part. But anyway, most current (August 2014) browsers can't handle
+    // strings 1 << 28 chars or longer, so:
+    if (str.length * count >= 1 << 28)
+        throw new RangeError('repeat count must not overflow maximum string size');
+
+    var maxCount = str.length * count;
+    count = Math.floor(Math.log(count) / Math.log(2));
+    while (count) {
+        str += str;
+        count--;
+    }
+    str += str.substring(0, maxCount - str.length);
+    return str;
+};
+
 /**
  * Modulo which works also for negative numbers (workaround for
  * ECMAScript modulo bug).
@@ -2577,7 +2633,12 @@ function getMainWindow() {
 }
 
 function getCurrentDateTime(format) {
-    return new QDateTime(QDateTime.currentDateTime()).toString(format);
+    if (RSettings.getQtVersion() >= 0x060000) {
+        return QDateTime.currentDateTime().toString(format);
+    }
+    else {
+        return new QDateTime(QDateTime.currentDateTime()).toString(format);
+    }
 }
 
 function mergeProperties(obj1,obj2) {
@@ -3202,6 +3263,18 @@ function makeQtItemFlags() {
     return makeFlags.apply(this, argumentsNew);
 }
 
+function makeQtKeyboardModifiers() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(Qt.KeyboardModifiers);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQtMouseButtons() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(Qt.MouseButtons);
+    return makeFlags.apply(this, argumentsNew);
+}
+
 function makeFlags() {
     if (RSettings.isQt(6)) {
         var ret = 0;
